#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const fs_extra_1 = require("fs-extra");
const util_1 = require("util");
const _glob = require("glob");
const cp = require("child_process");
const glob = util_1.promisify(_glob);
const exec = util_1.promisify(cp.exec);
(async () => {
    try {
        let configPath = process.argv[2];
        const cwd = process.cwd();
        // Get path to config file
        if (!configPath)
            configPath = path_1.resolve(cwd, 'gist-mirror.json');
        else if (!path_1.isAbsolute(configPath))
            configPath = path_1.resolve(cwd, configPath);
        // Load config file
        console.log(`Loading config from ${configPath}`);
        const config = await fs_extra_1.readJSON(configPath);
        const [, id] = config.gist.split('/');
        // Delete local gist if needed
        const gistDir = path_1.resolve(cwd, id);
        await fs_extra_1.remove(gistDir);
        // Load list of files from glob matches
        let filesPaths = [];
        for (let fileGlob of config.files) {
            filesPaths = filesPaths.concat(await glob(fileGlob));
        }
        filesPaths = [...new Set(filesPaths)];
        console.log('Found matching files');
        console.log(`\t${filesPaths.join('\n\t')}`);
        // Clone gist
        await exec(`git clone -q git@gist.github.com:${id}.git`);
        // Wipe gist
        const gistFiles = await glob(`${id}/**`);
        console.log('Wiping gist');
        for (let filePath of gistFiles.slice(1)) {
            const file = path_1.basename(filePath);
            console.log(`\t${file}`);
            await fs_extra_1.remove(path_1.resolve(gistDir, file));
        }
        // Copy in files and overwrite existing
        console.log('Copying files');
        for (let filePath of filesPaths) {
            const to = path_1.resolve(gistDir, path_1.basename(filePath));
            console.log(`\t${filePath} -> ${to}`);
            await fs_extra_1.copyFile(filePath, to);
        }
        // Commit and push changes
        await exec('git add -A', { cwd: gistDir });
        await exec('git commit -q -m "Mirror changes"', { cwd: gistDir });
        await exec('git push origin master', { cwd: gistDir });
        // Delete local gist
        await fs_extra_1.remove(gistDir);
        console.log('Mirroring complete');
    }
    catch (err) {
        console.error('Something went wrong...', err);
    }
})();
//# sourceMappingURL=gist-mirror.js.map